require("blender")


-- Define preset table, lets have 3 different tiles with different combinations
-- previously created in blender gui
presets = {
	{ {{22.5,-2,-2,2,2,0.25282304284404},"alpha",{255,255,255,255},false,2},
	{{0.2,-50,-10,50,10,0.25282304284404},"subtract",{255,255,255,255},false,3},
	{{0.2,-10,-50,10,50,0.25282304284404},"add",{255,255,255,255},false,3},
	{{0.5,-1,-1,1,1,0.11299402491284},"multiply",{255,228,192,255},false,255} },
	
	{ {{4.5,-5,-5,5,5,0.8124369429184},"alpha",{255,214,212,255},false,255},
	{{3.5,-1,-17,1,1,0.8124369429184},"subtract",{255,255,255,255},true,3},
	{{5.5,-17,-1,1,1,0.8124369429184},"screen",{159,159,159,255},true,7}
	 },
	 
	 {	{{11.5,-2,-2,2,2,0.25649083182104},"alpha",{255,255,255,255},false,3},
		{{3.5,-4,-1,4,1,0.10890028393558},"screen",{255,255,255,255},true,4},
		{{3.5,-1,-4,1,4,0.10890028393558},"multiply",{255,255,255,255},false,4}
	 }
}
-- Define preset count
preset_count = #presets

-- Define tile size, used in blender helper class and for graphics later
tile_width = 128
tile_height = 128

-- Declare our blender, seed parameter isnt necessary since we explicitly define in preset 
-- table above
blender = Blender:new(nil,tile_width,tile_height)

-- Declare simple map to show tiling behavior
map = {
	{1,1,1,1,1,1,1},
	{1,2,2,1,1,1,1},
	{1,2,2,2,1,1,1},
	{1,2,2,3,3,3,1},
	{1,1,2,3,3,3,1},
	{1,1,1,3,3,3,1},
	{1,1,1,1,1,1,1}
}


function love.load()
	-- Create atlas for our spritebatch
	-- since we are going do draw blender output to it, its going to be a canvas
	-- we align atlas horizonally
	atlas = love.graphics.newCanvas(tile_width*preset_count,tile_height)
	for i=1,preset_count do
		-- set parameter array for our blender
		blender:setParameters(presets[i])
		-- tell it to create blank texture batch
		blender:createBlankBatch()
		-- tell it to render layers
		blender:renderPreTex()
		-- tell it to put them all together
		blender:render()
		
		
		local prev_canvas = love.graphics.getCanvas()
		love.graphics.setCanvas(atlas)
		-- draw result onto our atlas
		love.graphics.draw(blender:getTexture(),(i-1)*tile_width)
		love.graphics.setCanvas(prev_canvas)
	end
	
	-- Create quads from atlas for our spritebatch
	quads = {}
	for i=1,preset_count do
		quads[i] = love.graphics.newQuad((i-1)*tile_width,0,tile_width,tile_height,atlas:getWidth(),atlas:getHeight())
	end
	
	-- Create our spritebatch
	local map_w,map_h = #map[1],#map
	spritebatch = love.graphics.newSpriteBatch(atlas,map_w*map_h,"static")
	
	-- Fill our spritebatch with tiles from map
	for y=1,#map do
		for x=1,#map[y] do
			spritebatch:add( quads[map[y][x]], (x-1)*tile_width, (y-1)*tile_height)
		end
	end
end

function love.draw()
	love.graphics.draw(spritebatch)
end